Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Decks ¶
type Decks struct {
// contains filtered or unexported fields
}
func NewDecks ¶
func NewDecks(ds models.DeckService) *Decks
func (*Decks) Create ¶
func (d *Decks) Create(w http.ResponseWriter, r *http.Request)
Create is used to create deck resource replies the request with created deck resource info and HTTP 201 code if succeed
POST /deck
Click to show internal directories.
Click to hide internal directories.